@@ -2,13 +2,14 @@ import sys
 from typing import Optional, TextIO, cast
 
 from prompt_toolkit.utils import (
+    get_bell_environment_variable,
     get_term_environment_variable,
     is_conemu_ansi,
-    is_windows,
 )
 
-from .base import Output
+from .base import DummyOutput, Output
 from .color_depth import ColorDepth
+from .plain_text import PlainTextOutput
 
 __all__ = [
     "create_output",
@@ -16,7 +17,7 @@ __all__ = [
 
 
 def create_output(
-    stdout: Optional[TextIO] = None, always_prefer_tty: bool = True
+    stdout: Optional[TextIO] = None, always_prefer_tty: bool = False
 ) -> Output:
     """
     Return an :class:`~prompt_toolkit.output.Output` instance for the command
@@ -24,14 +25,19 @@ def create_output(
 
     :param stdout: The stdout object
     :param always_prefer_tty: When set, look for `sys.stderr` if `sys.stdout`
-        is not a TTY. (The prompt_toolkit render output is not meant to be
-        consumed by something other then a terminal, so this is a reasonable
-        default.)
+        is not a TTY. Useful if `sys.stdout` is redirected to a file, but we
+        still want user input and output on the terminal.
+
+        By default, this is `False`. If `sys.stdout` is not a terminal (maybe
+        it's redirected to a file), then a `PlainTextOutput` will be returned.
+        That way, tools like `print_formatted_text` will write plain text into
+        that file.
     """
-    # Consider TERM and PROMPT_TOOLKIT_COLOR_DEPTH environment variables.
-    # Notice that PROMPT_TOOLKIT_COLOR_DEPTH value is the default that's used
-    # if the Application doesn't override it.
+    # Consider TERM, PROMPT_TOOLKIT_BELL, and PROMPT_TOOLKIT_COLOR_DEPTH
+    # environment variables. Notice that PROMPT_TOOLKIT_COLOR_DEPTH value is
+    # the default that's used if the Application doesn't override it.
     term_from_env = get_term_environment_variable()
+    bell_from_env = get_bell_environment_variable()
     color_depth_from_env = ColorDepth.from_env()
 
     if stdout is None:
@@ -41,10 +47,18 @@ def create_output(
 
         if always_prefer_tty:
             for io in [sys.stdout, sys.stderr]:
-                if io.isatty():
+                if io is not None and io.isatty():
+                    # (This is `None` when using `pythonw.exe` on Windows.)
                     stdout = io
                     break
 
+    # If the output is still `None`, use a DummyOutput.
+    # This happens for instance on Windows, when running the application under
+    # `pythonw.exe`. In that case, there won't be a terminal Window, and
+    # stdin/stdout/stderr are `None`.
+    if stdout is None:
+        return DummyOutput()
+
     # If the patch_stdout context manager has been used, then sys.stdout is
     # replaced by this proxy. For prompt_toolkit applications, we want to use
     # the real stdout.
@@ -53,7 +67,7 @@ def create_output(
     while isinstance(stdout, StdoutProxy):
         stdout = stdout.original_stdout
 
-    if is_windows():
+    if sys.platform == "win32":
         from .conemu import ConEmuOutput
         from .win32 import Win32Output
         from .windows10 import Windows10_Output, is_win_vt100_enabled
@@ -72,6 +86,15 @@ def create_output(
     else:
         from .vt100 import Vt100_Output
 
+        # Stdout is not a TTY? Render as plain text.
+        # This is mostly useful if stdout is redirected to a file, and
+        # `print_formatted_text` is used.
+        if not stdout.isatty():
+            return PlainTextOutput(stdout)
+
         return Vt100_Output.from_pty(
-            stdout, term=term_from_env, default_color_depth=color_depth_from_env
+            stdout,
+            term=term_from_env,
+            default_color_depth=color_depth_from_env,
+            enable_bell=bell_from_env,
         )
